#!/usr/bin/env python
import useful

useful.main.handle()